@@ -1,3 +1,4 @@
+import logging
 import math
 import re
 import string
@@ -19,9 +20,11 @@ everywhere="everywhere"
 
 def string_modifier(func):
     def wrapper(input, *args, **kwargs):
+        logging.debug("enter cleaning function")
         where=kwargs.get("where")
         if where:
             if where not in [start, end, start_and_end, everywhere]:
+                logging.debug("raise error from cleaning function")
                 raise ValueError("Invalid argument for where: "+where)
 
         if input is not None:  # if value is None, don't modify
@@ -33,9 +36,12 @@ def string_modifier(func):
             
             try:
                 input.value = res_string
+                logging.debug("returning from cleaning function")
                 return input
             except:
+                logging.debug("returning from cleaning function")
                 return res_string
+        logging.debug("returning from cleaning function")
         return input
     return wrapper
 
@@ -166,6 +172,20 @@ def pad(input, length, pad_text, where=start):
     if where == end:
         return input+ padding
 
+
+@string_modifier
+def strict_make_numeric(input, decimal="."):
+    input=strip_whitespace(str(input), where="everywhere")
+    if decimal!=".":
+        input=input.replace(".", "")
+        input=input.replace(decimal, ".")
+    input=input.replace(",", "")
+    try:
+        float(input)
+    except:
+        return "" #if it's not numeric, return an empty cell
+    return input
+
 @string_modifier
 def make_numeric(input, decimal=".", latex=False):
     '''make-numeric:
