@@ -1,4 +1,5 @@
-from t2wml.input_processing.annotation_parsing import annotation_suggester, Annotation, basic_block_finder
+from t2wml.input_processing.annotation_suggesting import annotation_suggester,  block_finder
+from t2wml.input_processing.annotation_parsing import Annotation
 from t2wml.api import Sheet
 
 
@@ -38,7 +39,7 @@ italy,"July 4, 2012",200,11"""
     a=Annotation(annotations)
     print(a.generate_yaml())
 
-def test_blocks():
+def test_blocks_from_csv():
     csv_string="""date qualifier,ugly numbers,numbers with stuff
 "",ethiopia,panama
 1998,10 000 000,$100
@@ -49,8 +50,13 @@ def test_blocks():
 "July 4, 2012",200,11"""
 
     s=Sheet.load_sheet_from_csv_string(csv_string, header=None)
-    basic_block_finder(s)
+    block_finder(s)
 
-s=Sheet(r"C:\Users\devora\C_sources\pedro\various files\homicide.csv", "homicide.csv")
-test=basic_block_finder(s)
-hi=1
\ No newline at end of file
+def test_block_from_sheet():
+    data_file=r"C:\Users\devora\C_sources\pedro\various files\coumntry-wikifier-bug\FreedomHousePressFreedomIndex.csv"
+    sheet_name="FreedomHousePressFreedomIndex.csv"
+    s=Sheet(data_file, sheet_name)
+    a=block_finder(s)
+    print(a)
+
+test_block_from_sheet()
\ No newline at end of file
